/*
 Class: BolderRaceUI
 Author: Shahrzad Jahangirian
 Date: March 14, 2014
 Description: This is the Bolder Race main Graphical User Interface. It is an 
 * user friendly desktop look alike screen that a computer illiterate operator can 
 * easily navigate different application options for use. It has large icons placed 
 * on screen for easy access to different application functionality.
 */
package GUIpkg;

import javax.swing.*;
import java.awt.*;
import java.awt.*;
import java.awt.Color;

import commonPKG.FormatUI;
import PDpkg.ConnectDatabase;
import PDpkg.Race;
import PDpkg.Registration;
import PDpkg.Winner;
import java.awt.event.*;

public class BolderRaceUI
        extends JFrame {

    private JMenuBar mainMenuBar = new JMenuBar();
    private JMenu fileMenu = new JMenu("File");
    private JMenuItem exitMenuItem = new JMenuItem("Exit");
    private JMenu participantMenu = new JMenu("Participant");
    private JMenuItem registerMenuItem = new JMenuItem("Register");
    private JMenuItem deleteMenuItem = new JMenuItem("Delete");
    private JMenuItem updateMenuItem = new JMenuItem("Update");
    private JMenu raceMenu = new JMenu("Race");
    private JMenuItem addRaceMenuItem = new JMenuItem("Add");
    private JMenuItem deleteRaceMenuItem = new JMenuItem("Delete");
    private JMenuItem updateRaceMenuItem = new JMenuItem("Update");
    private JMenu winnerMenu = new JMenu("Winner");
    private JMenuItem addWinnerMenuItem = new JMenuItem("Add");
    private JMenuItem deleteWinnerMenuItem = new JMenuItem("Delete");
    private JMenuItem updateWinnerMenuItem = new JMenuItem("Update");
    private JToolBar mainToolBar = new JToolBar();
    private JButton registerButton;
    private JButton raceButton;
    private JButton winnerButton;
    private JButton reportButton;
    private JPanel bodyPanel = new JPanel();
    private ImageIcon appIcon = new ImageIcon("icons/bolder.png");
    private ImageIcon registerIcon = new ImageIcon("icons/register.png");
    private JLabel registerIconLabel = new JLabel("Participant", registerIcon, JLabel.CENTER);
    private ImageIcon raceIcon = new ImageIcon("icons/race.png");
    private JLabel raceIconLabel = new JLabel("Race", raceIcon, JLabel.CENTER);
    private ImageIcon winnerIcon = new ImageIcon("icons/winner.png");
    private JLabel winnerIconLabel = new JLabel("Winner", winnerIcon, JLabel.CENTER);
    private ImageIcon reportIcon = new ImageIcon("icons/report.png");
    private JLabel reportIconLabel = new JLabel("Report", reportIcon, JLabel.CENTER);
    private ImageIcon exitIcon = new ImageIcon("icons/exit.png");
    private JLabel exitIconLabel = new JLabel("EXIT", exitIcon, JLabel.CENTER);
    private JPanel statusBarPanel = new JPanel();
    private RegisterUI registerUI;
    private RaceUI raceUI = new RaceUI();
    private WinnerUI winnerUI = new WinnerUI();
    private ConnectDatabase connect = new ConnectDatabase();
    private FormatUI format = new FormatUI();
    private Race race = new Race();
    private Registration reg = new Registration();
    private Winner winner = new Winner();

    public BolderRaceUI() {
        try {
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    public void jbInit() {

        setupMenuBar();
        setupToolBar();
        bodyPanel = format.createBodyPanel(bodyPanel, 96, 104, 113, 800, 700);
        statusBarPanel = format.createStatusBar(statusBarPanel, 250, 250, 250, 800, 25);
        format.centerFrame(this);
        addListeners();
        addIcons();

        this.setSize(800, 700);
        this.setExtendedState(Frame.MAXIMIZED_BOTH);
        this.setJMenuBar(mainMenuBar);
        this.getContentPane().setLayout(new BorderLayout());
        this.getContentPane().add(mainToolBar, BorderLayout.PAGE_START);
        this.getContentPane().add(bodyPanel, BorderLayout.CENTER);
        this.getContentPane().add(statusBarPanel, BorderLayout.PAGE_END);
        this.getContentPane().setBackground(new Color(96, 104, 113));
        this.setIconImage(appIcon.getImage());
        this.setTitle("Bolder Boulder Races");
        this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
        this.setResizable(true);
        this.setVisible(true);
    }

    public void addIcons() {
        registerIconLabel = format.formatIconLabel(registerIconLabel, 50, 25, 250,
                125, 96, 104, 113, 250, 250, 250, "Arial", 1,
                14, JLabel.BOTTOM, JLabel.CENTER);
        raceIconLabel = format.formatIconLabel(raceIconLabel, 50, 150, 250,
                125, 96, 104, 113, 250, 250, 250, "Arial", 1,
                14, JLabel.BOTTOM, JLabel.CENTER);
        winnerIconLabel = format.formatIconLabel(winnerIconLabel, 50, 275, 250,
                125, 96, 104, 113, 250, 250, 250, "Arial", 1,
                14, JLabel.BOTTOM, JLabel.CENTER);
        reportIconLabel = format.formatIconLabel(reportIconLabel, 50, 400, 250,
                125, 96, 104, 113, 250, 250, 250, "Arial", 1,
                14, JLabel.BOTTOM, JLabel.CENTER);
        exitIconLabel = format.formatIconLabel(exitIconLabel, 400, 400, 250,
                125, 96, 104, 113, 250, 250, 250, "Arial", 1,
                14, JLabel.BOTTOM, JLabel.CENTER);

        bodyPanel.add(registerIconLabel, null);
        bodyPanel.add(raceIconLabel, null);
        bodyPanel.add(winnerIconLabel, null);
        bodyPanel.add(reportIconLabel, null);
        bodyPanel.add(exitIconLabel, null);
    }

    public void setupMenuBar() {
        mainMenuBar = format.formatJMenuBar(mainMenuBar, 0, 0, 792, 30, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        fileMenu = format.formatJMenu(fileMenu, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        exitMenuItem = format.formatJMenuItem(exitMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        fileMenu.add(exitMenuItem);

        participantMenu = format.formatJMenu(participantMenu, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        registerMenuItem = format.formatJMenuItem(registerMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        updateMenuItem = format.formatJMenuItem(updateMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        deleteMenuItem = format.formatJMenuItem(deleteMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        participantMenu.add(registerMenuItem);
        participantMenu.add(updateMenuItem);
        participantMenu.add(deleteMenuItem);

        raceMenu = format.formatJMenu(raceMenu, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        addRaceMenuItem = format.formatJMenuItem(addRaceMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        updateRaceMenuItem = format.formatJMenuItem(updateRaceMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        deleteRaceMenuItem = format.formatJMenuItem(deleteRaceMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        raceMenu.add(addRaceMenuItem);
        raceMenu.add(updateRaceMenuItem);
    //    raceMenu.add(deleteRaceMenuItem);

        winnerMenu = format.formatJMenu(winnerMenu, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        addWinnerMenuItem = format.formatJMenuItem(addWinnerMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        updateWinnerMenuItem = format.formatJMenuItem(updateWinnerMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        deleteWinnerMenuItem = format.formatJMenuItem(deleteWinnerMenuItem, 250, 250, 250, 96, 104, 113, "Arial", 0, 14);
        winnerMenu.add(addWinnerMenuItem);
        winnerMenu.add(updateWinnerMenuItem);
        winnerMenu.add(deleteWinnerMenuItem);

        mainMenuBar.add(fileMenu);
        mainMenuBar.add(participantMenu);
        mainMenuBar.add(raceMenu);
        mainMenuBar.add(winnerMenu);
    }

    public void setupToolBar() {
        mainToolBar = format.formatJToolBar(mainToolBar, 250, 250, 250);
        registerButton = format.formatJToolBarButton(registerButton, "icons/register_th.png", 4,
                4, 4, 4, 1, 1, 1, 1, 250, 250, 250, false, false, "Register");
        raceButton = format.formatJToolBarButton(registerButton, "icons/race_th.png", 4,
                4, 4, 4, 1, 1, 1, 1, 250, 250, 250, false, false, "Race");
        winnerButton = format.formatJToolBarButton(registerButton, "icons/winner_th.png", 4,
                4, 4, 4, 1, 1, 1, 1, 250, 250, 250, false, false, "Winner");
        reportButton = format.formatJToolBarButton(registerButton, "icons/report_th.png", 4,
                4, 4, 4, 1, 1, 1, 1, 250, 250, 250, false, false, "Report");
        mainToolBar.add(registerButton);
        mainToolBar.add(raceButton);
        mainToolBar.add(winnerButton);
        mainToolBar.add(reportButton);
    }

    public void addListeners() {
        exitMenuItem.addActionListener(new BolderRaceUI_exitMenuItem_actionAdapter(this));
        this.addWindowListener(new BolderRaceUI_this_windowAdapter(this));
        registerButton.addActionListener(new BolderRaceUI_registerButton_actionAdapter(this));
        registerIconLabel.addMouseListener(new BolderRaceUI_registerIconLabel_mouseAdapter(this));
        raceButton.addActionListener(new BolderRaceUI_raceButton_actionAdapter(this));
        winnerButton.addActionListener(new BolderRaceUI_winnerButton_actionAdapter(this));
        reportButton.addActionListener(new BolderRaceUI_reportButton_actionAdapter(this));
        raceIconLabel.addMouseListener(new BolderRaceUI_raceIconLabel_mouseAdapter(this));
        winnerIconLabel.addMouseListener(new BolderRaceUI_winnerIconLabel_mouseAdapter(this));
        reportIconLabel.addMouseListener(new BolderRaceUI_reportIconLabel_mouseAdapter(this));
        exitIconLabel.addMouseListener(new BolderRaceUI_exitIconLabel_mouseAdapter(this));
        registerMenuItem.addActionListener(new BolderRaceUI_registerMenuItem_actionAdapter(this));
        updateMenuItem.addActionListener(new BolderRaceUI_updateMenuItem_actionAdapter(this));
        deleteMenuItem.addActionListener(new BolderRaceUI_deleteMenuItem_actionAdapter(this));
        addRaceMenuItem.addActionListener(new BolderRaceUI_addRaceMenuItem_actionAdapter(this));
        updateRaceMenuItem.addActionListener(new BolderRaceUI_updateRaceMenuItem_actionAdapter(this));
        deleteRaceMenuItem.addActionListener(new BolderRaceUI_deleteRaceMenuItem_actionAdapter(this));
        addWinnerMenuItem.addActionListener(new BolderRaceUI_addWinnerMenuItem_actionAdapter(this));
        updateWinnerMenuItem.addActionListener(new BolderRaceUI_updateWinnerMenuItem_actionAdapter(this));
        deleteWinnerMenuItem.addActionListener(new BolderRaceUI_deleteWinnerMenuItem_actionAdapter(this));
    }

    public void displayRegScreen() {
        if (race.isRaceEmpty()) {
            JOptionPane.showMessageDialog(this, "Enter Race First, there is no Race in Database");
        } else {
            registerUI = new RegisterUI();
            registerUI.setVisible(true);
        }
    }

    public void displayWinnerScreen() {
        if (race.isRaceEmpty()) {
            JOptionPane.showMessageDialog(this, "Enter Races, there is no Race in Database");
        } else if (reg.isParticipantEmpty()) {
            JOptionPane.showMessageDialog(this, "Enter Participants, there is no Participant in Database");
        } else {
            winnerUI.clear();
            winnerUI.setStatusBar("");
            winnerUI.setVisible(true);
        }
    }

    void registerButton_actionPerformed(ActionEvent e) {
        displayRegScreen();
    }

    void exitMenuItem_actionPerformed(ActionEvent e) {
        connect.closeAll();
        System.exit(0);
    }

    void this_windowClosing(WindowEvent e) {
        connect.closeAll();
        System.exit(0);
    }

    void registerIconLabel_mouseClicked(MouseEvent e) {
        displayRegScreen();
    }

    void raceButton_actionPerformed(ActionEvent e) {
        addRace();
    }

    void winnerButton_actionPerformed(ActionEvent e) {
        displayWinnerScreen();
    }

    void reportButton_actionPerformed(ActionEvent e) {
        JOptionPane.showMessageDialog(this, "to be completed in Part 3");
    }

    void raceIconLabel_mouseClicked(MouseEvent e) {
        addRace();
    }

    void winnerIconLabel_mouseClicked(MouseEvent e) {
        displayWinnerScreen();
    }

    void reportIconLabel_mouseClicked(MouseEvent e) {
        JOptionPane.showMessageDialog(this, "to be completed in Part 3");
    }

    void exitIconLabel_mouseClicked(MouseEvent e) {
        connect.closeAll();
        System.exit(0);
    }

    void registerMenuItem_actionPerformed(ActionEvent e) {
        displayRegScreen();
    }

    void updateMenuItem_actionPerformed(ActionEvent e) {
        if (reg.isParticipantEmpty()) {
            JOptionPane.showMessageDialog(this, "There is no Participant to Update");
        } else {
            displayRegScreen();
            registerUI.clear();
            registerUI.setTitle("Update a Participant");
            registerUI.setStatusBar("Enter a Social Security Number to find and update a Participant");
            registerUI.setActionButtons(false, true, false, true);
            registerUI.setVisible(true);
        }
    }

    void deleteMenuItem_actionPerformed(ActionEvent e) {
        if (reg.isParticipantEmpty()) {
            JOptionPane.showMessageDialog(this, "There is no Participant to Delete");
        } else {
            displayRegScreen();
            registerUI.clear();
            registerUI.setTitle("Delete a Participant");
            registerUI.setStatusBar(" Enter a Social Security Number to find and delete a Participant");
            registerUI.setActionButtons(false, true, true, false);
            registerUI.setVisible(true);
        }
    }

    public void addRace() {
        raceUI.clear();
        raceUI.setTitle("Add a Race");
        raceUI.setStatusBar(" Add a Race Carefully, You can not delete a Race.");
        raceUI.setActionButtons(true, true, false, false);
        raceUI.setVisible(true);
    }

    void addRaceMenuItem_actionPerformed(ActionEvent e) {
        addRace();
    }

    void updateRaceMenuItem_actionPerformed(ActionEvent e) {
        if (race.isRaceEmpty()) {
            JOptionPane.showMessageDialog(this, "Enter Races, there is no Race in Database to Update");
        } else {
            raceUI.clear();
            raceUI.setTitle("Update a Race");
            raceUI.setStatusBar(" Enter a Race ID to update a Race");
            raceUI.setActionButtons(false, true, false, true);
            raceUI.setVisible(true);
        }
    }

    void deleteRaceMenuItem_actionPerformed(ActionEvent e) {
        if (race.isRaceEmpty()) {
            JOptionPane.showMessageDialog(this, "Enter Races, there is no Race in Database to Delete");
        } else {
            raceUI.clear();
            raceUI.setTitle("Delete a Race");
            raceUI.setStatusBar("Enter a Race ID to delete a Race");
            raceUI.setActionButtons(false, true, true, false);
            raceUI.setVisible(true);
        }
    }

    void addWinnerMenuItem_actionPerformed(ActionEvent e) {
        displayWinnerScreen();
    }

    void updateWinnerMenuItem_actionPerformed(ActionEvent e) {
        if (winner.isWinnerEmpty()) {
            JOptionPane.showMessageDialog(this, "Enter Winners, there is no Winner in Database to Update");
        } else {
            winnerUI.clear();
            winnerUI.setTitle("Update a Winner");
            winnerUI.setStatusBar("Enter a Race ID & a Social Security Number to update a Winner");
            winnerUI.setActionButtons(false, true, false, true);
            winnerUI.setVisible(true);
        }
    }

    void deleteWinnerMenuItem_actionPerformed(ActionEvent e) {
        if (winner.isWinnerEmpty()) {
            JOptionPane.showMessageDialog(this, "Enter Winners, there is no Winner in Database to Delete");
        } else {
            winnerUI.clear();
            winnerUI.setTitle("Delete a Winner");
            winnerUI.setStatusBar("Enter a Race ID & a Social Security Number to delete a Winner");
            winnerUI.setActionButtons(false, true, true, false);
            winnerUI.setVisible(true);
        }
    }
}

class BolderRaceUI_registerButton_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_registerButton_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.registerButton_actionPerformed(e);
    }
}

class BolderRaceUI_exitMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_exitMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.exitMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_this_windowAdapter extends java.awt.event.WindowAdapter {

    BolderRaceUI adaptee;

    BolderRaceUI_this_windowAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void windowClosing(WindowEvent e) {
        adaptee.this_windowClosing(e);
    }
}

class BolderRaceUI_registerIconLabel_mouseAdapter extends java.awt.event.MouseAdapter {

    BolderRaceUI adaptee;

    BolderRaceUI_registerIconLabel_mouseAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void mouseClicked(MouseEvent e) {
        adaptee.registerIconLabel_mouseClicked(e);
    }
}

class BolderRaceUI_raceButton_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_raceButton_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.raceButton_actionPerformed(e);
    }
}

class BolderRaceUI_winnerButton_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_winnerButton_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.winnerButton_actionPerformed(e);
    }
}

class BolderRaceUI_reportButton_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_reportButton_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.reportButton_actionPerformed(e);
    }
}

class BolderRaceUI_raceIconLabel_mouseAdapter extends java.awt.event.MouseAdapter {

    BolderRaceUI adaptee;

    BolderRaceUI_raceIconLabel_mouseAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void mouseClicked(MouseEvent e) {
        adaptee.raceIconLabel_mouseClicked(e);
    }
}

class BolderRaceUI_winnerIconLabel_mouseAdapter extends java.awt.event.MouseAdapter {

    BolderRaceUI adaptee;

    BolderRaceUI_winnerIconLabel_mouseAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void mouseClicked(MouseEvent e) {
        adaptee.winnerIconLabel_mouseClicked(e);
    }
}

class BolderRaceUI_reportIconLabel_mouseAdapter extends java.awt.event.MouseAdapter {

    BolderRaceUI adaptee;

    BolderRaceUI_reportIconLabel_mouseAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void mouseClicked(MouseEvent e) {
        adaptee.reportIconLabel_mouseClicked(e);
    }
}

class BolderRaceUI_exitIconLabel_mouseAdapter extends java.awt.event.MouseAdapter {

    BolderRaceUI adaptee;

    BolderRaceUI_exitIconLabel_mouseAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void mouseClicked(MouseEvent e) {
        adaptee.exitIconLabel_mouseClicked(e);
    }
}

class BolderRaceUI_registerMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_registerMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.registerMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_addRaceMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_addRaceMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.addRaceMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_addWinnerMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_addWinnerMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.addWinnerMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_updateMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_updateMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.updateMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_updateRaceMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_updateRaceMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.updateRaceMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_updateWinnerMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_updateWinnerMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.updateWinnerMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_deleteMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_deleteMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.deleteMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_deleteRaceMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_deleteRaceMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.deleteRaceMenuItem_actionPerformed(e);
    }
}

class BolderRaceUI_deleteWinnerMenuItem_actionAdapter implements java.awt.event.ActionListener {

    BolderRaceUI adaptee;

    BolderRaceUI_deleteWinnerMenuItem_actionAdapter(BolderRaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.deleteWinnerMenuItem_actionPerformed(e);
    }
}
