/*
 Class: ParticipantDB
 Author: Shahrzad Jahangirian
 Update Date: March 26, 2014
 Description: This class does all database manipulation for PARTICIPANT table of BOLDER Database.
 It extends ConnectionDB class.
 */
package DBpkg;

import java.sql.*;
import java.util.*;
import java.lang.*;
import java.lang.Integer;

import PDpkg.Participant;
import DBpkg.WinnerDB;

public class ParticipantDB extends ConnectionDB {

    private Participant person = new Participant();
    private boolean isWinner = false;

    public ParticipantDB() {
        
    }
    
      public boolean isParticipantEmpty() {
        boolean empty = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from PARTICIPANT");           
            rs = query.executeQuery();
            if (!rs.next()) {
                empty = true;
            }
        } catch (Exception ex) {
            System.err.println("SQLException isParticipantEmpty" + ex.getMessage());
        } 
        return empty;
    }

    public int getNextId() {
        int id = 0;
        ArrayList<Integer> idList = new ArrayList<Integer>();        
        try {
            query = con.prepareStatement("select participantId from PARTICIPANT");
            rs = query.executeQuery();
            while (rs.next()) {
                idList.add(Integer.valueOf(rs.getInt(1)));
            }
            Collections.sort(idList);
            int lastIndex = idList.size() - 1;
            Integer ref = idList.get(lastIndex);
            id = ref.intValue();
            id++;
        } catch (Exception ex) {
           // System.err.println("SQLException getNextId" + ex.getMessage());
        }
        return id;
    }

    public boolean isSsnDuplicate(String ssnId) {
        boolean duplicate = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from PARTICIPANT where ssn = ?");
            query.setString(1, ssnId);
            rs = query.executeQuery();
            if (rs.first()) {
                duplicate = true;                
                fillRecord();
            }
        } catch (Exception ex) {
            System.err.println("SQLException isSsnDuplicate" + ex.getMessage());
        }
        return duplicate;
    }
    
    public boolean isSsnExist(String ssnId) {
        boolean exist = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from PARTICIPANT where ssn = ?");
            query.setString(1, ssnId);
            rs = query.executeQuery();
            if (rs.first()) {
                exist = true;                
                fillRecord();
            }
        } catch (Exception ex) {
            System.err.println("SQLException isSsnExist" + ex.getMessage());
        }
        return exist;
    }

    public void fillRecord() {
        person = new Participant();
        try {
            person.setId(rs.getInt(1));
            person.setSsn(rs.getString(2));
            person.setName(rs.getString(3));
            person.setSurname(rs.getString(4));
            person.setNickname(rs.getString(5));
            person.setBirthDate(rs.getString(6));
            person.setAge(rs.getInt(7));
            person.setPr(rs.getString(8));
            person.setAddress1(rs.getString(9));
            person.setAddress2(rs.getString(10));
            person.setCity(rs.getString(11));
            person.setState(rs.getString(12));
            person.setZip(rs.getString(13));
            person.setCountry(rs.getString(14));
            person.setEmail(rs.getString(15));
            person.setGender(rs.getString(16));
            person.setMobile(rs.getString(17));
            person.setPhone(rs.getString(18));
            person.setEmergPhone(rs.getString(19));
            person.setRaceType(rs.getString(20));
            person.setRaceId(rs.getInt(21));

        } catch (Exception ex) {
            System.err.println("SQLException fillRecord: " + ex.getMessage());
        }
    }

    public Participant getRecord() {
        return person;
    }

    public void displayList(ArrayList<Integer> list) {
        for (int i = 0; i < list.size(); i++) {
            System.out.println(i + "idList " + list.get(i));
        }

    }

    public boolean saveParticipant(Participant record) {
        boolean ok = true;
        try {
            query = con.prepareStatement(
                    "insert into PARTICIPANT values"
                    + "(?,?, ?, ?, ?, ?, ?,?, ?, ?, ?, ?, ?, ?,?, ?, ?, ?, ?, ?, ?)");

            query.setInt(1, record.getId());
            query.setString(2, record.getSsn());
            query.setString(3, record.getName());
            query.setString(4, record.getSurname());
            query.setString(5, record.getNickname());
            query.setString(6, record.getBirthDate());
            query.setInt(7, record.getAge());
            query.setString(8, record.getPr());
            query.setString(9, record.getAddress1());
            query.setString(10, record.getAddress2());
            query.setString(11, record.getCity());
            query.setString(12, record.getState());
            query.setString(13, record.getZip());
            query.setString(14, record.getCountry());
            query.setString(15, record.getEmail());
            query.setString(16, record.getGender());
            query.setString(17, record.getMobile());
            query.setString(18, record.getPhone());
            query.setString(19, record.getEmergPhone());
            query.setString(20, record.getRaceType());
            query.setInt(21, record.getRaceId());
            query.executeUpdate();
        } catch (SQLException ex) {
            ok = false;
            System.err.println("SQLException saveParticipant: " + ex.getMessage());
        }
        return ok;
    }

    public boolean updateParticipant(Participant record) {
        boolean ok = true;
        try {
            query = con.prepareStatement(
                    "update PARTICIPANT set ssn=?,name=?,surname=?,nickname=?, birthdate=?,"
                    + "age=?,pr=?,address1=?,address2=?,city=?,state=?,zip=?,country=?,email=?,"
                    + "gender=?,mobile=?,phone=?,emergencyPhone=?,racetype=?,raceid=? where participantId = ?");
            
            query.setString(1, record.getSsn());
            query.setString(2, record.getName());
            query.setString(3, record.getSurname());
            query.setString(4, record.getNickname());
            query.setString(5, record.getBirthDate());
            query.setInt(6, record.getAge());
            query.setString(7, record.getPr());
            query.setString(8, record.getAddress1());
            query.setString(9, record.getAddress2());
            query.setString(10, record.getCity());
            query.setString(11, record.getState());
            query.setString(12, record.getZip());
            query.setString(13, record.getCountry());
            query.setString(14, record.getEmail());
            query.setString(15, record.getGender());
            query.setString(16, record.getMobile());
            query.setString(17, record.getPhone());
            query.setString(18, record.getEmergPhone());
            query.setString(19, record.getRaceType());
            query.setInt(20, record.getRaceId());
            query.setInt(21, record.getId());
            query.executeUpdate();
        } catch (SQLException ex) {
            ok = false;
            System.err.println("SQLException updateParticipant: " + ex.getMessage());
        }
        return ok;
    }
    
   public String findSSN(int id){
         String ssnStr = new String();
        try {
            rs = null;
            query = con.prepareStatement("select ssn from PARTICIPANT where participantId = ?");
            query.setInt(1, id);
            rs = query.executeQuery();
            if (rs.first()) {
                ssnStr = rs.getString(1);
            }
        } catch (Exception ex) {
            System.err.println("SQLException findSSn" + ex.getMessage());
        }
        return ssnStr;
    } 
    
    public boolean deleteParticipant(int id,String ssn){       
         boolean ok = true;
         isWinner = false;
        WinnerDB winnerdb = new WinnerDB();
        boolean exist = winnerdb.isSsnId(ssn);
        if (exist == true) {
            ok = false;
            isWinner = true;
        } else {
        try {
            query = con.prepareStatement(
                    "delete from PARTICIPANT where participantId = ?");
            query.setInt(1, id);
            query.executeUpdate();
             } catch (SQLException ex) {
            ok = false;
            System.err.println("SQLException deleteParticipant: " + ex.getMessage());
        }
        }
        return ok;       
    }
    
    public boolean isSsnInWinner(){
        return isWinner;
    }
    
       public boolean isRaceId(int id) {
        boolean exist = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Participant where raceId = ?");
            query.setInt(1, id);           
            rs = query.executeQuery();
            if (rs.first()) {
                exist = true;                               
            }
        } catch (Exception ex) {
          //  System.err.println("SQLException isWinnerExist" + ex.getMessage());
        } 
        return exist;
    }
  
}
