/*
 Class: RaceDB
 Author: Shahrzad Jahangirian
 Update Date: May 2, 2014
 Description: This class does all database manipulation for Race table of BOLDER Database.
 It extends ConnectionDB class.
 */
package DBpkg;

import java.sql.*;
import java.util.*;
import java.lang.*;
import java.lang.Integer;

import PDpkg.RaceInfo;
import DBpkg.WinnerDB;

public class RaceDB extends ConnectionDB {

    private RaceInfo raceinfo = new RaceInfo();
    private ArrayList<RaceInfo> raceList = new ArrayList<RaceInfo>();
    private boolean isWinner = false;

    public RaceDB() {
    }

    public boolean isRaceIdDuplicate(int id) {
        boolean duplicate = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Race where raceId = ?");
            query.setInt(1, id);
            rs = query.executeQuery();
            if (rs.first()) {
                duplicate = true;
                fillRecord();
            }
        } catch (Exception ex) {
            //   System.err.println("SQLException isRaceIdDuplicate" + ex.getMessage());
        }
        return duplicate;
    }

    public boolean isRaceEmpty() {
        boolean empty = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Race");
            rs = query.executeQuery();
            if (!rs.next()) {
                empty = true;
            }
        } catch (Exception ex) {
            //  System.err.println("SQLException isRaceEmpty" + ex.getMessage());
        }
        return empty;
    }

    public boolean isRaceIdExist(int id) {
        boolean exist = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Race where raceId = ?");
            query.setInt(1, id);
            rs = query.executeQuery();
            if (rs.first()) {
                exist = true;
                fillRecord();
            }
        } catch (Exception ex) {
            //   System.err.println("SQLException isRaceIdExist" + ex.getMessage());
        }
        return exist;
    }

    public ArrayList getAllRaces() {
        try {
            rs = null;
            query = con.prepareStatement("select * from Race");
            rs = query.executeQuery();
            while (rs.next()) {
                fillRecord();
                raceList.add(raceinfo);
            }
        } catch (Exception ex) {
            //    System.err.println("SQLException getAllRaces" + ex.getMessage());
        }
        return raceList;
    }

    public void fillRecord() {
        raceinfo = new RaceInfo();
        try {
            raceinfo.setRaceId(rs.getInt(1));
            raceinfo.setRaceDate(rs.getString(2));
            raceinfo.setRaceTime(rs.getString(3));
            raceinfo.setRaceName(rs.getString(4));

        } catch (Exception ex) {
            //     System.err.println("SQLException fillRecord: " + ex.getMessage());
        }
    }

    public RaceInfo getRecord() {
        return raceinfo;
    }

    public boolean saveRace(RaceInfo record) {
        boolean ok = true;
        try {
            query = con.prepareStatement(
                    "insert into RACE values"
                    + "(?,?, ?, ?)");

            query.setInt(1, record.getRaceId());
            query.setString(2, record.getRaceDate());
            query.setString(3, record.getRaceTime());
            query.setString(4, record.getRaceName());
            query.executeUpdate();
        } catch (SQLException ex) {
            ok = false;
            //   System.err.println("SQLException saveRace: " + ex.getMessage());
        }
        return ok;
    }

    public boolean updateRace(RaceInfo record) {
        boolean ok = true;
        try {
            query = con.prepareStatement(
                    "update RACE set raceDate=?,raceTime=?,raceName=? where raceId = ?");

            query.setString(1, record.getRaceDate());
            query.setString(2, record.getRaceTime());
            query.setString(3, record.getRaceName());
            query.setInt(4, record.getRaceId());
            query.executeUpdate();
        } catch (SQLException ex) {
            ok = false;
            //   System.err.println("SQLException updateRace: " + ex.getMessage());
        }
        return ok;
    }
    
    public boolean isRaceInWinner(){
        return isWinner;
    }
      
    public boolean deleteRace(int id) {
        boolean ok = true;
        isWinner = false;      
        WinnerDB winnerdb = new WinnerDB();  
        boolean exist = winnerdb.isRaceId(id);
        if (exist == true) {           
            ok = false;
            isWinner = true;
        }     
         else {
            try {               
                query = con.prepareStatement(
                        "delete from Race where raceId = ?");
                query.setInt(1, id);
                query.executeUpdate();
            } catch (SQLException ex) {
                ok = false;
                   System.err.println("SQLException deleteRace: " + ex.getMessage());
            }
        }
        return ok;
    }
}
