/*
 Class: RaceUI
 Author: Shahrzad Jahangirian
 Date: May 2, 2014
 Description: A data entry screen for add, update, and delete a Race in 
 * annual Bolder Boulder Races.
 */
package GUIpkg;

import javax.swing.*;
import java.awt.*;
import java.awt.*;
import java.awt.Color;
import java.awt.event.*;
import java.util.*;
import java.text.*;

import commonPKG.FormatUI;
import commonPKG.CustomDateTime;
import commonPKG.CustomMath;
import PDpkg.Race;
import PDpkg.RaceInfo;

public class RaceUI
        extends JFrame {

    private JPanel bodyPanel = new JPanel();
    private JPanel statusBarPanel = new JPanel();
    private JLabel statusBarLabel = new JLabel();
    private JLabel raceIdLabel = new JLabel();
    private JLabel raceNameLabel = new JLabel();
    private JLabel raceDateLabel = new JLabel();
    private JLabel raceTimeLabel = new JLabel();
    private JTextField raceIdTextField = new JTextField();
    private JTextField raceNameTextField = new JTextField();
    private JTextField raceDateTextField = new JTextField();
    private JTextField raceTimeTextField = new JTextField();
    private JButton saveButton = new JButton();
    private JButton clearButton = new JButton();
    private JButton deleteButton = new JButton();
    private JButton updateButton = new JButton();
    private Date calendar;
    private SimpleDateFormat sdf;
    private String dateString = new String();
    private FormatUI format = new FormatUI();
    private String dupRaceId = new String();
    private boolean raceIdFocus = false;
    private boolean raceIdTyped = false;
    private ImageIcon raceIcon = new ImageIcon("icons/race_th.png");
    private CustomDateTime cDateTime = new CustomDateTime();
    private CustomMath cMath = new CustomMath();
    private RaceInfo raceinfo = new RaceInfo();
    private Race race = new Race();
    private RaceInfo updateRace = new RaceInfo();

    public RaceUI() {
        try {
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    public void jbInit() {

        bodyPanel = format.formatPanel(bodyPanel, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12);
        bodyPanel.setLayout(null);
        statusBarPanel = format.createStatusBar(statusBarPanel, 240, 240, 240, 800,
                25);
        formatUserInterfaces();
        addListeners();
        addToPanel();
        setActionButtons(true, true, false, false);

        this.setSize(767, 200);
        format.centerFrame(this);
        this.setResizable(false);
        this.getContentPane().setLayout(new BorderLayout());
        this.getContentPane().add(bodyPanel, null);
        this.getContentPane().add(statusBarPanel, BorderLayout.PAGE_END);
        this.getContentPane().setBackground(new Color(250, 250, 250));
        this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
        this.setIconImage(raceIcon.getImage());
        this.setTitle("Add a Race");
    }

    public void setActionButtons(boolean saveFlag, boolean clearFlag, boolean delFlag, boolean updateFlag) {
        saveButton.setVisible(saveFlag);
        clearButton.setVisible(clearFlag);
     //   deleteButton.setVisible(delFlag);
        updateButton.setVisible(updateFlag);
    }

    public void setStatusBar(String msg) {
        statusBarLabel.setText(msg);
    }

    public void formatUserInterfaces() {
        statusBarLabel = format.formatLabel(statusBarLabel,
                "", 1, 1,
                750, 20, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        raceIdLabel = format.formatLabel(raceIdLabel,
                "Race ID", 16, 10,
                150, 17, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        raceIdTextField = format.formatTextField(raceIdTextField, "", 15,
                30, 175, 25, 255, 255, 255, 96,
                104, 113, "Arial", 0, 12, 0);
        raceNameLabel = format.formatLabel(raceNameLabel,
                "Race Name", 201, 10,
                150, 17, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        raceNameTextField = format.formatTextField(raceNameTextField, "", 200,
                30, 250, 25, 255, 255, 255, 96,
                104, 113, "Arial", 0, 12, 0);
        raceDateLabel = format.formatLabel(raceDateLabel,
                "Race Date", 461, 10,
                125, 17, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        calendar = new GregorianCalendar(TimeZone.getDefault()).getTime();
        sdf = new SimpleDateFormat("d/MM/yyyy");
        dateString = sdf.format(calendar);
        raceDateTextField = format.formatTextField(raceDateTextField, dateString,
                460,
                30, 137, 25, 255, 255, 255, 96,
                104, 113, "Arial", 0, 12, 0);
        raceTimeLabel = format.formatLabel(raceTimeLabel,
                "Race Time", 608, 10,
                75, 17, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        raceTimeTextField = format.formatTextField(raceTimeTextField, "", 607,
                30, 137, 25, 255, 255, 255, 96,
                104, 113, "Arial", 0, 12, 0);
        saveButton = format.formatButton(saveButton, "Save", 570, 85, 83, 25, 96,
                104, 113, "Arial", 0, 12);
        updateButton = format.formatButton(updateButton, "Update", 570, 85, 83, 25,
                96,
                104, 113, "Arial", 0, 12);
        deleteButton = format.formatButton(deleteButton, "Delete", 478, 85, 83, 25,
                96,
                104, 113, "Arial", 0, 12);
        clearButton = format.formatButton(clearButton, "Clear", 662, 85, 83, 25,
                96,
                104, 113, "Arial", 0, 12);

    }

    public void addListeners() {
        clearButton.addActionListener(new RaceUI_clearButton_actionAdapter(this));
        saveButton.addActionListener(new RaceUI_saveButton_actionAdapter(this));
        raceIdTextField.addFocusListener(new RaceUI_raceIdTextField_focusAdapter(this));
        raceIdTextField.addKeyListener(new RaceUI_raceIdTextField_keyAdapter(this));
        deleteButton.addActionListener(new RaceUI_deleteButton_actionAdapter(this));
        updateButton.addActionListener(new RaceUI_updateButton_actionAdapter(this));
    }

    public void addToPanel() {
        statusBarPanel.add(statusBarLabel);
        bodyPanel.add(raceIdLabel);
        bodyPanel.add(raceIdTextField);
        bodyPanel.add(raceNameLabel);
        bodyPanel.add(raceNameTextField);
        bodyPanel.add(raceDateLabel);
        bodyPanel.add(raceDateTextField);
        bodyPanel.add(raceTimeLabel);
        bodyPanel.add(raceTimeTextField);
        bodyPanel.add(updateButton);
     //   bodyPanel.add(deleteButton);
        bodyPanel.add(saveButton);
        bodyPanel.add(clearButton);
    }

    void clearButton_actionPerformed(ActionEvent e) {
        clear();
    }

    public void clear() {
        raceIdTextField.setText("");
        raceNameTextField.setText("");
        raceDateTextField.setText(dateString);
        raceTimeTextField.setText("");
        statusBarLabel.setText("");
        raceIdTextField.setEditable(true);
        raceIdTextField.setBackground(new Color(255, 255, 255));
        setActionButtons(true, true, false, false);
        this.setTitle("Add a Race");
    }

    public boolean validateEntries() {
        boolean valid = true;

        if ((raceIdTextField.getText().trim().length() > 10)
                || (raceIdTextField.getText().trim().equals("") == true)
                || (cMath.isInteger(raceIdTextField.getText().trim()) == false)
                || (cMath.isGreaterThanZero(raceIdTextField.getText().trim()) == false)) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Race Id must be a Number Greater than 0 and to maximum of 10 Digits.");
            Toolkit.getDefaultToolkit().beep();
        } else if (raceNameTextField.getText().trim().length() > 300) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Maximum of 300 Characters are allowed for Race Name.");
            Toolkit.getDefaultToolkit().beep();
        } else if (cDateTime.validateDate(raceDateTextField.getText().trim()) == false) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Date of Race must be in dd/mm/yyyy format.");
            Toolkit.getDefaultToolkit().beep();
        } else if (raceTimeTextField.getText().trim().length() > 20) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Maximum of 20 Characters are allowed for Race Time.");
            Toolkit.getDefaultToolkit().beep();
        }
        return valid;
    }

    public void allocateRecord() {
        raceinfo = new RaceInfo();

        raceinfo.setRaceId(Integer.parseInt(raceIdTextField.getText().trim()));
        raceinfo.setRaceDate(raceDateTextField.getText().trim());
        raceinfo.setRaceTime(raceTimeTextField.getText().trim());
        raceinfo.setRaceName(raceNameTextField.getText().trim());

    }

    public void saveButton_actionPerformed(ActionEvent e) {
        boolean valid = false;
        boolean saved = false;
        valid = validateEntries();
        if (valid == true) {
            allocateRecord();
            saved = race.addRace(raceinfo);
            if (saved == true) {
                clear();
                statusBarLabel.setText(raceinfo.getRaceId() + " Number has been added successfully.");
            } else {
                statusBarLabel.setText("ERROR: " + raceinfo.getRaceId() + " has not been Saved");
            }
        }
    }

    void raceIdTextField_focusGained(FocusEvent e) {
        raceIdFocus = true;
    }

    void raceIdTextField_keyTyped(KeyEvent e) {
        raceIdTyped = true;
    }

    public boolean validateRaceIdTextFieldEntry() {
        boolean valid = true;
        if ((raceIdTextField.getText().trim().length() > 10)
                || (raceIdTextField.getText().trim().equals("") == true)
                || (cMath.isInteger(raceIdTextField.getText().trim()) == false)
                || (cMath.isGreaterThanZero(raceIdTextField.getText().trim()) == false)) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Race Id must be a Number Greater than 0 and to maximum of 10 Digits.");
            Toolkit.getDefaultToolkit().beep();
        }
        return valid;
    }

    void raceIdTextField_focusLost(FocusEvent e) {
        updateRace = new RaceInfo();
        if ((raceIdFocus == true) && (raceIdTyped == true)) {
            if (validateRaceIdTextFieldEntry() == true) {
                updateRace = race.validateRaceId(Integer.parseInt(raceIdTextField.getText().trim()));
            }
            if (updateRace.getRaceId() > 0) {
                dupRaceId = raceIdTextField.getText().trim();
                statusBarLabel.setText("Duplicate Entry: " + dupRaceId + " is already Exist. You are allowed to update all fields except Race ID");
                displayRecord(updateRace);
                raceIdTextField.setEditable(false);
                raceIdTextField.setBackground(new Color(217, 233, 238));
                setActionButtons(false, true, true, true);
                this.setTitle("Update A Race");
            } else {
                raceIdTextField.setEditable(true);
                raceIdTextField.setBackground(new Color(255, 255, 255));
            }
        }
        raceIdFocus = false;
        raceIdTyped = false;

    }

    public void displayRecord(RaceInfo raceline) {
        raceIdTextField.setText(String.valueOf(raceline.getRaceId()));
        raceNameTextField.setText(raceline.getRaceName());
        raceDateTextField.setText(raceline.getRaceDate());
        raceTimeTextField.setText(raceline.getRaceTime());
    }

    void deleteButton_actionPerformed(ActionEvent e) {
        boolean delFlag = false;
        Object[] options = {"Yes", "No", "Cancel"};
        this.setTitle("Delete A Race");
        int response = JOptionPane.showOptionDialog(this,
                "Are you sure you want to permanently delete this Race?",
                "Confirm Delete",
                JOptionPane.YES_NO_CANCEL_OPTION,
                JOptionPane.WARNING_MESSAGE,
                null,
                options,
                options[2]);
        if (response == 0) {
            
            delFlag = race.deleteRace(updateRace.getRaceId());
        }
        if (delFlag == true) {
            statusBarLabel.setText(updateRace.getRaceId() + " has been Removed from Database.");
            clear();
        } else {
            boolean flag = race.isRaceInWinner();         
            if (flag == true) {
                statusBarLabel.setText("ERROR: There is a Winner with this Race ID, Delete the Winner First.");
            }           
            else {
                statusBarLabel.setText("ERROR: " + updateRace.getRaceId() + " has not removed from Database");
            }
        }
    }

    void updateButton_actionPerformed(ActionEvent e) {
        boolean valid = false;
        boolean updated = false;
        valid = validateEntries();
        if (valid == true) {
            allocateRecord();
            raceinfo.setRaceId(updateRace.getRaceId());
            updated = race.updateRace(raceinfo);
            if (updated == true) {
                clear();
                statusBarLabel.setText(raceinfo.getRaceId() + " Race has been updated successfully.");
            } else {
                statusBarLabel.setText("ERROR: " + raceinfo.getRaceId() + " Race update has not been Saved");


            }
        }
    }
}

class RaceUI_clearButton_actionAdapter
        implements java.awt.event.ActionListener {

    RaceUI adaptee;

    RaceUI_clearButton_actionAdapter(RaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.clearButton_actionPerformed(e);
    }
}

class RaceUI_saveButton_actionAdapter
        implements java.awt.event.ActionListener {

    RaceUI adaptee;

    RaceUI_saveButton_actionAdapter(RaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.saveButton_actionPerformed(e);
    }
}

class RaceUI_raceIdTextField_focusAdapter extends java.awt.event.FocusAdapter {

    RaceUI adaptee;

    RaceUI_raceIdTextField_focusAdapter(RaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void focusGained(FocusEvent e) {
        adaptee.raceIdTextField_focusGained(e);
    }

    public void focusLost(FocusEvent e) {
        adaptee.raceIdTextField_focusLost(e);
    }
}

class RaceUI_raceIdTextField_keyAdapter extends java.awt.event.KeyAdapter {

    RaceUI adaptee;

    RaceUI_raceIdTextField_keyAdapter(RaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void keyTyped(KeyEvent e) {
        adaptee.raceIdTextField_keyTyped(e);
    }
}

class RaceUI_deleteButton_actionAdapter implements java.awt.event.ActionListener {

    RaceUI adaptee;

    RaceUI_deleteButton_actionAdapter(RaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.deleteButton_actionPerformed(e);
    }
}

class RaceUI_updateButton_actionAdapter implements java.awt.event.ActionListener {

    RaceUI adaptee;

    RaceUI_updateButton_actionAdapter(RaceUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.updateButton_actionPerformed(e);
    }
}
