/*
 Class: WinnerDB
 Author: Shahrzad Jahangirian
 Update Date: June 21, 2014
 Description: This class does all database manipulation for Winner table of BOLDER Database.
 It extends ConnectionDB class.
 */
package DBpkg;

import java.sql.*;
import java.util.*;
import java.lang.*;
import java.lang.Integer;

import PDpkg.WinnerInfo;

public class WinnerDB extends ConnectionDB {

    private WinnerInfo winnerinfo = new WinnerInfo();

    public WinnerDB() {
        
    }
    
    public boolean isWinnerEmpty() {
        boolean empty = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Winner");           
            rs = query.executeQuery();
            if (!rs.next()) {
                empty = true;
            }
        } catch (Exception ex) {
        //    System.err.println("SQLException isWinnerEmpty" + ex.getMessage());
        } 
        return empty;
    }

    public boolean isWinnerDuplicate(int id, String ssn) {
        boolean duplicate = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Winner where raceId = ? and ssn = ?");
            query.setInt(1, id);
            query.setString(2, ssn);
            rs = query.executeQuery();
            if (rs.first()) {
                duplicate = true;                
                fillRecord();
            }
        } catch (Exception ex) {
         //   System.err.println("SQLException isWinnerDuplicate" + ex.getMessage());
        } 
        return duplicate;
    }
    
    public boolean isWinnerExist(int id, String ssn) {
        boolean exist = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Winner where raceId = ? and ssn = ?");
            query.setInt(1, id);
            query.setString(2, ssn);
            rs = query.executeQuery();
            if (rs.first()) {
                exist = true;                
                fillRecord();
            }
        } catch (Exception ex) {
          //  System.err.println("SQLException isWinnerExist" + ex.getMessage());
        } 
        return exist;
    }
    
    public boolean isRaceId(int id) {
        boolean exist = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Winner where raceId = ?");
            query.setInt(1, id);           
            rs = query.executeQuery();
            if (rs.first()) {
                exist = true;                               
            }
        } catch (Exception ex) {
          //  System.err.println("SQLException isWinnerExist" + ex.getMessage());
        } 
        return exist;
    }
    
    public boolean isSsnId(String id) {
        boolean exist = false;
        try {
            rs = null;
            query = con.prepareStatement("select * from Winner where ssn = ?");
            query.setString(1, id);           
            rs = query.executeQuery();
            if (rs.first()) {
                exist = true;                               
            }
        } catch (Exception ex) {
          //  System.err.println("SQLException isWinnerExist" + ex.getMessage());
        } 
        return exist;
    }

    public void fillRecord() {
        winnerinfo = new WinnerInfo();
        try {
            winnerinfo.setRaceId(rs.getInt(1));
            winnerinfo.setSSN(rs.getString(2));
            winnerinfo.setMaster(rs.getBoolean(3));             

        } catch (Exception ex) {
        //    System.err.println("SQLException fillRecord: " + ex.getMessage());
        } 
    }

    public WinnerInfo getRecord() {
        return winnerinfo;
    }


    public boolean saveWinner(WinnerInfo record) {
        boolean ok = true;
        try {
            query = con.prepareStatement(
                    "insert into Winner values"
                    + "(?,?, ?)");

            query.setInt(1, record.getRaceId());
            query.setString(2, record.getSSN());
            query.setBoolean(3, record.getMaster());                    
            query.executeUpdate();
        } catch (SQLException ex) {
            ok = false;
        //    System.err.println("SQLException saveWinner: " + ex.getMessage());
        } 
        return ok;
    }

    public boolean updateWinner(WinnerInfo record) {
        boolean ok = true;
        try {
            query = con.prepareStatement(
                    "update Winner set Master=? where raceId = ? and ssn = ?");
            
            query.setBoolean(1, record.getMaster());
            query.setInt(2, record.getRaceId());
            query.setString(3, record.getSSN());                     
            query.executeUpdate();
        } catch (SQLException ex) {
            ok = false;
        //    System.err.println("SQLException updateWinner: " + ex.getMessage());
        } 
        return ok;
    }
    
    public boolean deleteWinner(int id, String ssn){       
         boolean ok = true;
        try {           
            query = con.prepareStatement(
                    "delete from Winner where raceId = ? and ssn = ?");
            query.setInt(1, id);
            query.setString(2, ssn);
            query.executeUpdate();
             } catch (SQLException ex) {
            ok = false;
         //   System.err.println("SQLException deleteWinner: " + ex.getMessage());
        } 
        return ok;       
    }
}
