/*
 Class: WinnerUI
 Author: Shahrzad Jahangirian
 Date: June 21, 2014
 Description: A data entry screen for add, update, and delete a Race Winner in 
 * annual Bolder Boulder Races.
 */
package GUIpkg;

import javax.swing.*;
import java.awt.*;
import java.awt.*;
import java.awt.Color;
import java.awt.event.*;
import java.util.*;
import java.text.*;

import commonPKG.FormatUI;
import commonPKG.CustomMath;
import PDpkg.Winner;
import PDpkg.WinnerInfo;

public class WinnerUI
        extends JFrame {

    private JPanel bodyPanel = new JPanel();
    private JPanel statusBarPanel = new JPanel();
    private JLabel statusBarLabel = new JLabel();
    private JLabel raceIdLabel = new JLabel();
    private JLabel ssnLabel = new JLabel();
    private JLabel masterLabel = new JLabel();
    private JTextField raceIdTextField = new JTextField();
    private JTextField ssnTextField = new JTextField();
    private String[] masterString = {"YES", "NO"};
    private JComboBox masterComboBox = new JComboBox(masterString);
    private JButton saveButton = new JButton();
    private JButton clearButton = new JButton();
    private JButton deleteButton = new JButton();
    private JButton updateButton = new JButton();
    private FormatUI format = new FormatUI();
    private String dupRaceId = new String();
    private boolean raceIdFocus = false;
    private boolean raceIdTyped = false;
    private ImageIcon raceIcon = new ImageIcon("icons/winner_th.png");
    private WinnerInfo winnerinfo = new WinnerInfo();
    private Winner winner = new Winner();
    private WinnerInfo updateWinner = new WinnerInfo();
    private CustomMath cMath = new CustomMath();

    public WinnerUI() {
        try {
            jbInit();
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    public void jbInit() {

        bodyPanel = format.formatPanel(bodyPanel, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12);
        bodyPanel.setLayout(null);
        statusBarPanel = format.createStatusBar(statusBarPanel, 240, 240, 240, 800,
                25);
        formatUserInterfaces();
        addListeners();
        addToPanel();
        setActionButtons(true, true, false, false);

        this.setSize(767, 200);
        format.centerFrame(this);
        this.setResizable(false);
        this.getContentPane().setLayout(new BorderLayout());
        this.getContentPane().add(bodyPanel, null);
        this.getContentPane().add(statusBarPanel, BorderLayout.PAGE_END);
        this.getContentPane().setBackground(new Color(250, 250, 250));
        this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
        this.setIconImage(raceIcon.getImage());
        this.setTitle("Add A Winner");
    }

    public void setActionButtons(boolean saveFlag, boolean clearFlag, boolean delFlag, boolean updateFlag) {
        saveButton.setVisible(saveFlag);
        clearButton.setVisible(clearFlag);
        deleteButton.setVisible(delFlag);
        updateButton.setVisible(updateFlag);
    }

    public void setStatusBar(String msg) {
        statusBarLabel.setText(msg);
    }

    public void formatUserInterfaces() {
        statusBarLabel = format.formatLabel(statusBarLabel,
                "", 1, 1,
                750, 20, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        raceIdLabel = format.formatLabel(raceIdLabel,
                "Race ID", 16, 10,
                150, 17, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        raceIdTextField = format.formatTextField(raceIdTextField, "", 15,
                30, 175, 25, 255, 255, 255, 96,
                104, 113, "Arial", 0, 12, 0);
        ssnLabel = format.formatLabel(ssnLabel,
                "Social Security Number", 201, 10,
                150, 17, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        ssnTextField = format.formatTextField(ssnTextField, "", 200,
                30, 250, 25, 255, 255, 255, 96,
                104, 113, "Arial", 0, 12, 0);
        masterLabel = format.formatLabel(masterLabel,
                "Master", 461, 10,
                125, 17, 240, 240, 240, 96, 104, 113,
                "Arial", 0, 12, SwingConstants.CENTER,
                SwingConstants.LEFT);
        masterComboBox = format.formatComboBox(masterComboBox, 460, 30, 137, 25, false, false,
                0, 255, 255, 255, 96, 104, 113,
                "Arial", 0, 12, 3);
        saveButton = format.formatButton(saveButton, "Save", 570, 85, 83, 25, 96,
                104, 113, "Arial", 0, 12);
        updateButton = format.formatButton(updateButton, "Update", 570, 85, 83, 25,
                96,
                104, 113, "Arial", 0, 12);
        deleteButton = format.formatButton(deleteButton, "Delete", 478, 85, 83, 25,
                96,
                104, 113, "Arial", 0, 12);
        clearButton = format.formatButton(clearButton, "Clear", 662, 85, 83, 25,
                96,
                104, 113, "Arial", 0, 12);

    }

    public void addListeners() {
        clearButton.addActionListener(new WinnerUI_clearButton_actionAdapter(this));
        saveButton.addActionListener(new WinnerUI_saveButton_actionAdapter(this));
        raceIdTextField.addFocusListener(new WinnerUI_raceIdTextField_focusAdapter(this));
        raceIdTextField.addKeyListener(new WinnerUI_raceIdTextField_keyAdapter(this));
        deleteButton.addActionListener(new WinnerUI_deleteButton_actionAdapter(this));
        updateButton.addActionListener(new WinnerUI_updateButton_actionAdapter(this));
    }

    public void addToPanel() {
        statusBarPanel.add(statusBarLabel);
        bodyPanel.add(raceIdLabel);
        bodyPanel.add(raceIdTextField);
        bodyPanel.add(ssnLabel);
        bodyPanel.add(ssnTextField);
        bodyPanel.add(masterLabel);
        bodyPanel.add(masterComboBox);
        bodyPanel.add(updateButton);
        bodyPanel.add(deleteButton);
        bodyPanel.add(saveButton);
        bodyPanel.add(clearButton);
    }

    void clearButton_actionPerformed(ActionEvent e) {
        clear();
    }

    public void clear() {
        raceIdTextField.setText("");
        ssnTextField.setText("");
        statusBarLabel.setText("");
        raceIdTextField.setEditable(true);
        ssnTextField.setEditable(true);
        raceIdTextField.setBackground(new Color(255, 255, 255));
        ssnTextField.setBackground(new Color(255, 255, 255));
        setActionButtons(true, true, false, false);
        this.setTitle("Add A Winner");
    }

    public boolean validateEntries() {
        boolean valid = true;

        if ((raceIdTextField.getText().trim().length() > 10)
                || (raceIdTextField.getText().trim().equals("") == true)
                || (cMath.isInteger(raceIdTextField.getText().trim()) == false)
                || (cMath.isGreaterThanZero(raceIdTextField.getText().trim()) == false)) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Race Id must be a Number Greater than 0 and to maximum of 10 Digits.");
            Toolkit.getDefaultToolkit().beep();
        } else if ((ssnTextField.getText().trim().length() > 35)
                || (ssnTextField.getText().trim().equals("") == true)) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Maximum of 35 Characters are allowed for Social Security Number.");
            Toolkit.getDefaultToolkit().beep();
        }
        return valid;
    }

    public void allocateRecord() {
        winnerinfo = new WinnerInfo();

        winnerinfo.setRaceId(Integer.parseInt(raceIdTextField.getText().trim()));
        winnerinfo.setSSN(ssnTextField.getText().trim());
        if ((masterComboBox.getSelectedItem().toString()).equals("YES") == true) {
            winnerinfo.setMaster(true);
        } else {
            winnerinfo.setMaster(false);
        }

    }

    public void saveButton_actionPerformed(ActionEvent e) {
        boolean valid = false;
        boolean saved = false;

        valid = validateEntries();
        if (valid == true) {
            if (winner.isParticipantSSN(ssnTextField.getText().trim()) == false) {
                valid = false;
                statusBarLabel.setText(ssnTextField.getText().trim() + " does not exist in Database. Please try again.");
            } else if (winner.isRaceId(Integer.parseInt(raceIdTextField.getText().trim())) == false) {
                valid = false;
                statusBarLabel.setText(raceIdTextField.getText().trim() + " does not exist in Database. Please try again.");
            } else if (validateDuplicate() == true) {
                valid = false;
                raceIdTextField.setEditable(false);
                ssnTextField.setEditable(false);
                raceIdTextField.setBackground(new Color(217,233,238));
                ssnTextField.setBackground(new Color(217,233,238));
            } else {
                valid = true;
                raceIdTextField.setEditable(true);
                ssnTextField.setEditable(true);
                raceIdTextField.setBackground(new Color(255, 255, 255));
                ssnTextField.setBackground(new Color(255, 255, 255));
            }
        }
        if (valid == true) {
            allocateRecord();
            saved = winner.addWinner(winnerinfo);
            if (saved == true) {
                clear();
                statusBarLabel.setText("Winner with SSN No: " + winnerinfo.getSSN() + " for Race "
                        + winnerinfo.getRaceId() + " has been added successfully.");
            } else {
                statusBarLabel.setText("Error: Winner with SSN No: " + winnerinfo.getSSN() + " for Race "
                        + winnerinfo.getRaceId() + " has not been Saved");
            }
        }
    }

    void raceIdTextField_focusGained(FocusEvent e) {
        raceIdFocus = true;
    }

    void raceIdTextField_keyTyped(KeyEvent e) {
        raceIdTyped = true;
    }

    public boolean validateRaceIdTextFieldEntry() {
        boolean valid = true;
        if ((raceIdTextField.getText().trim().length() > 10)
                || (raceIdTextField.getText().trim().equals("") == true)
                || (cMath.isInteger(raceIdTextField.getText().trim()) == false)
                || (cMath.isGreaterThanZero(raceIdTextField.getText().trim()) == false)) {
            valid = false;
            statusBarLabel.setText(
                    " Error: Race Id must be a Number Greater than 0 and to maximum of 10 Digits.");
            Toolkit.getDefaultToolkit().beep();
        }
        return valid;
    }

    public boolean validateDuplicate() {
        updateWinner = new WinnerInfo();
        updateWinner = winner.isDuplicateEntry(Integer.parseInt(raceIdTextField.getText().trim()), ssnTextField.getText().trim());
        boolean dup = false;
        if (updateWinner.getRaceId() > 0) {
            statusBarLabel.setText("Duplicate Entry, this record is already in Database. You are only allowed to update Master.");
            displayRecord(updateWinner);
            setActionButtons(false, true, true, true);
            this.setTitle("Update A Winner");
            dup = true;
        }
        return dup;
    }
   

    public void displayRecord(WinnerInfo winnerline) {
        raceIdTextField.setText(String.valueOf(winnerline.getRaceId()));
        ssnTextField.setText(winnerline.getSSN());
        if (winnerline.getMaster() == true) {
            masterComboBox.setSelectedIndex(0);
        } else {
            masterComboBox.setSelectedIndex(1);
        }
    }

    void deleteButton_actionPerformed(ActionEvent e) {
        boolean delFlag = false;
        Object[] options = {"Yes", "No", "Cancel"};
        this.setTitle("Delete A Winner");
        int response = JOptionPane.showOptionDialog(this,
                "Are you sure you want to permanently delete this Winner?",
                "Confirm Delete",
                JOptionPane.YES_NO_CANCEL_OPTION,
                JOptionPane.WARNING_MESSAGE,
                null,
                options,
                options[2]);
        if (response == 0) {          
            delFlag = winner.deleteWinner(Integer.parseInt(raceIdTextField.getText().trim()), ssnTextField.getText().trim());                 
            if (delFlag == true) {
                statusBarLabel.setText("Winner with SSN No: " + winnerinfo.getSSN() + " for Race "
                        + winnerinfo.getRaceId() + " has been Removed from Database.");
                clear();
            } else {
                statusBarLabel.setText("Error: Winner with SSN No: " + winnerinfo.getSSN() + " for Race "
                        + winnerinfo.getRaceId() + " has not been removed from Database");
            }
        }
    }

    void updateButton_actionPerformed(ActionEvent e) {
        boolean valid = false;
        boolean updated = false;
        valid = validateEntries();
        if (valid == true) {
            allocateRecord();
            winnerinfo.setRaceId(updateWinner.getRaceId());
            updated = winner.updateWinner(winnerinfo);
            if (updated == true) {
                clear();
                statusBarLabel.setText("Winner with SSN No: " + updateWinner.getSSN() + " for Race "
                        + updateWinner.getRaceId() + " has been updated successfully.");
            } else {
                statusBarLabel.setText("Error: Winner with SSN No: " + updateWinner.getSSN() + " for Race "
                        + updateWinner.getRaceId() + " update has not been Saved");
            }
        }
    }
}

class WinnerUI_clearButton_actionAdapter
        implements java.awt.event.ActionListener {

    WinnerUI adaptee;

    WinnerUI_clearButton_actionAdapter(WinnerUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.clearButton_actionPerformed(e);
    }
}

class WinnerUI_saveButton_actionAdapter
        implements java.awt.event.ActionListener {

    WinnerUI adaptee;

    WinnerUI_saveButton_actionAdapter(WinnerUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.saveButton_actionPerformed(e);
    }
}

class WinnerUI_raceIdTextField_focusAdapter extends java.awt.event.FocusAdapter {

    WinnerUI adaptee;

    WinnerUI_raceIdTextField_focusAdapter(WinnerUI adaptee) {
        this.adaptee = adaptee;
    }

    public void focusGained(FocusEvent e) {
        adaptee.raceIdTextField_focusGained(e);
    }

}

class WinnerUI_raceIdTextField_keyAdapter extends java.awt.event.KeyAdapter {

    WinnerUI adaptee;

    WinnerUI_raceIdTextField_keyAdapter(WinnerUI adaptee) {
        this.adaptee = adaptee;
    }

    public void keyTyped(KeyEvent e) {
        adaptee.raceIdTextField_keyTyped(e);
    }
}

class WinnerUI_deleteButton_actionAdapter implements java.awt.event.ActionListener {

    WinnerUI adaptee;

    WinnerUI_deleteButton_actionAdapter(WinnerUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.deleteButton_actionPerformed(e);
    }
}

class WinnerUI_updateButton_actionAdapter implements java.awt.event.ActionListener {

    WinnerUI adaptee;

    WinnerUI_updateButton_actionAdapter(WinnerUI adaptee) {
        this.adaptee = adaptee;
    }

    public void actionPerformed(ActionEvent e) {
        adaptee.updateButton_actionPerformed(e);
    }
}
